/*
	libtsd

	Thread-Specific Data support library
	Copyright 1997 by Christopher Tate
*/

#pragma once

#ifndef tsd_h
#define tsd_h 1

#ifdef __cplusplus
extern "C" {
#endif

/* tsd_key_t is to be considered an OPAQUE type! */

typedef void* tsd_key_t;

/*
   The API is almost, but not quite, the same as the pthread_* API
   Arguments which are modified are given names starting with 'out',
   those read by the function with 'in', and those both used and
   returned with 'inout'.  This is similar to those keywords in IDL.
*/

/*
	tsd_key_create() return codes:
		EAGAIN - no more available keys
		ENOMEM - out of memory trying to allocate key
*/

int   tsd_key_create(tsd_key_t *outKey);

/*
	tsd_key_delete() return codes:
		EINVAL - no such key exists
*/

int   tsd_key_delete(tsd_key_t inKey);

/*
	tsd_setspecific() return codes:
		ENOMEM - out of memory trying to associate value with key
*/

int   tsd_setspecific(tsd_key_t inKey, const void* inValue);

/*
	tsd_getspecific() returns NULL when no such key exists
*/

void* tsd_getspecific(tsd_key_t inKey);

#ifdef __cplusplus
}
#endif

/* Constant - the maximum number of concurrently-active TSD keys */

#define TSD_KEYS_MAX		128

#endif	/* ifndef tsd_h */
